==> mobiusft-1.19.zip: mobiusft-1.19/src/python/mobius/io/func_to_win_path.cc <==
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
// Mobius Forensic Toolkit
// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020 Eduardo Aguiar
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any later
// version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
// Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <http://www.gnu.org/licenses/>.
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=

// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
//! \brief  C++ API module wrapper
//! \author Eduardo Aguiar
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
#include <pymobius.h>
#include "path.h"

// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
//! \brief Function to_win_path
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
PyObject*
func_to_win_path (PyObject *, PyObject *args)
{
  // Get function argument (string or path object)
  PyObject *arg = nullptr;

  try
    {
      arg = mobius::py::get_arg (args, 0);
    }
  catch (const std::exception& e)
    {
      PyErr_SetString (PyExc_ValueError, e.what ());
      return nullptr;
    }

  mobius::io::path path;

  if (mobius::py::pystring_check (arg))
    path = mobius::io::path (mobius::py::pystring_as_std_string (arg));

  else if (PyMobius_Io_Path_Check (arg))
    path = PyMobius_Io_Path_as_cpp (arg);

  else
    {
      PyErr_SetString (PyExc_TypeError, "invalid argument");
      return nullptr;
    }

  // execute C++ code
  PyObject *ret = nullptr;

  try
    {
      ret = mobius::py::pystring_from_std_string (to_win_path (path));
    }
  catch (const std::exception& e)
    {
      PyErr_SetString (PyExc_ValueError, e.what ());
    }

  return ret;
}

==> mobiusft-1.25.zip: mobiusft-1.25/src/python/mobius/io/func_to_win_path.cc <==
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
// Mobius Forensic Toolkit
// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022 Eduardo Aguiar
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any later
// version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
// Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <http://www.gnu.org/licenses/>.
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=

// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
//! \brief  C++ API module wrapper
//! \author Eduardo Aguiar
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
#include <pymobius.h>
#include "path.h"

// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
//! \brief Function to_win_path
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
PyObject*
func_to_win_path (PyObject *, PyObject *args)
{
  // Get function argument (string or path object)
  PyObject *arg = nullptr;

  try
    {
      arg = mobius::py::get_arg (args, 0);
    }
  catch (const std::exception& e)
    {
      PyErr_SetString (PyExc_ValueError, e.what ());
      return nullptr;
    }

  mobius::io::path path;

  if (mobius::py::pystring_check (arg))
    path = mobius::io::path (mobius::py::pystring_as_std_string (arg));

  else if (pymobius_io_path_check (arg))
    path = pymobius_io_path_from_pyobject (arg);

  else
    {
      PyErr_SetString (PyExc_TypeError, "invalid argument");
      return nullptr;
    }

  // execute C++ code
  PyObject *ret = nullptr;

  try
    {
      ret = mobius::py::pystring_from_std_string (to_win_path (path));
    }
  catch (const std::exception& e)
    {
      PyErr_SetString (PyExc_ValueError, e.what ());
    }

  return ret;
}
